==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QCborError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcborcommon.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCborError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborError")
    QCborError *_ptr = reinterpret_cast<QCborError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCborError_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCborError *__qt_this = new(__qtjambi_ptr) QCborError();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCborError
void __qt_destruct_QCborError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborError")
    reinterpret_cast<QCborError*>(ptr)->~QCborError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCborError::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_initialize_1native__Lio_qt_core_QCborError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborError::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborError_0, sizeof(QCborError), typeid(QCborError), false, &deleter_QCborError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCborError::operator==(QCborError,QCborError)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_equals_1native_1cref_1QCborError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborError::operator==(QCborError,QCborError)", __qt_this)
        const QCborError& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCborError>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCborError::toString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_toString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborError::toString()const", __qt_this)
        QString __qt_return_value = __qt_this->toString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_setCode_1native_1cref_1QCborError_1Code__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCborError::Code __qt_code0 = qtjambi_cast<QCborError::Code>(__jni_env, code0);
        __qt_this->c = QCborError::Code(__qt_code0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_code_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError::Code&  __qt_value = __qt_this->c;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCborError>("QCborError", "io/qt/core/QCborError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCborError, {
        ConstructorInfo(&__qt_construct_QCborError_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QCborError::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborError);
    registerMetaType<QCborError>("QCborError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QCborError::Code>("QCborError::Code", "io/qt/core/QCborError$Code");
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QCborError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcborcommon.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCborError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborError")
    QCborError *_ptr = reinterpret_cast<QCborError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCborError()
void __qt_construct_QCborError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborError()")
    Q_UNUSED(__java_arguments)
    QCborError *__qt_this = new(__qtjambi_ptr) QCborError();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCborError::QCborError()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_initialize_1native__Lio_qt_core_QCborError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborError::QCborError()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborError, sizeof(QCborError), typeid(QCborError), false, &deleter_QCborError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCborError(QCborError)
void __qt_construct_QCborError_cref_QCborError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborError(QCborError)")
    jobject other0 = __java_arguments[0].l;
    const QCborError& __qt_other0 = qtjambi_cast<const QCborError& >(__jni_env, other0);
    QCborError *__qt_this = new(__qtjambi_ptr) QCborError(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCborError::QCborError(QCborError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_initialize_1native__Lio_qt_core_QCborError_2Lio_qt_core_QCborError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborError::QCborError(QCborError)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborError_cref_QCborError, sizeof(QCborError), typeid(QCborError), false, &deleter_QCborError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCborError{QCborError::Code}
void __qt_construct_QCborError_QCborError_Code(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborError{QCborError::Code}")
    jobject c0 = __java_arguments[0].l;
    QCborError::Code __qt_c0 = qtjambi_cast<QCborError::Code>(__jni_env, c0);
    QCborError *__qt_this = new(__qtjambi_ptr) QCborError{QCborError::Code(__qt_c0)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCborError::QCborError{QCborError::Code}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_initialize_1native__Lio_qt_core_QCborError_2Lio_qt_core_QCborError_00024Code_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject c0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborError::QCborError{QCborError::Code}")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = c0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborError_QCborError_Code, sizeof(QCborError), typeid(QCborError), false, &deleter_QCborError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCborError
void __qt_destruct_QCborError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborError")
    reinterpret_cast<QCborError*>(ptr)->~QCborError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCborError::operator==(QCborError,QCborError)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_equals_1native_1cref_1QCborError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborError::operator==(QCborError,QCborError)", __qt_this)
        const QCborError& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCborError>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCborError::toString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_toString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborError::toString()const", __qt_this)
        QString __qt_return_value = __qt_this->toString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_setCode_1native_1cref_1QCborError_1Code__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint code0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCborError::Code __qt_code0 = qtjambi_cast<QCborError::Code>(__jni_env, code0);
        __qt_this->c = QCborError::Code(__qt_code0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_code_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError::Code&  __qt_value = __qt_this->c;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCborError *__qt_this = QtJambiAPI::objectFromNativeId<QCborError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCborError>("QCborError", "io/qt/core/QCborError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCborError, {
        ConstructorInfo(&__qt_construct_QCborError, nullptr)
       ,ConstructorInfo(&__qt_construct_QCborError_cref_QCborError, "Lio/qt/core/QCborError;")
       ,ConstructorInfo(&__qt_construct_QCborError_QCborError_Code, "Lio/qt/core/QCborError$Code;")
    });
// END: function table

    registerMetaObject(typeId, QCborError::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborError);
    registerMetaType<QCborError>("QCborError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QCborError::Code>("QCborError::Code", "io/qt/core/QCborError$Code");
// END: enums and flags
}
